package com.muyu.product.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.product.domain.CategoryAttribute;
import com.muyu.product.service.ICategoryAttributeService;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 品类属性中间Controller
 *
 * @author Saisai
 * @date 2024-02-29
 */
@RestController
@RequestMapping("/category_attribute")
public class CategoryAttributeController extends BaseController
{
    @Autowired
    private ICategoryAttributeService categoryAttributeService;

    /**
     * 查询品类属性中间列表
     */
    @RequiresPermissions("product:category_attribute:list")
    @GetMapping("/list")
    public Result<TableDataInfo<CategoryAttribute>> list(CategoryAttribute categoryAttribute)
    {
        startPage();
        List<CategoryAttribute> list = categoryAttributeService.selectCategoryAttributeList(categoryAttribute);
        return getDataTable(list);
    }

    /**
     * 导出品类属性中间列表
     */
    @RequiresPermissions("product:category_attribute:export")
    @Log(title = "品类属性中间", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CategoryAttribute categoryAttribute)
    {
        List<CategoryAttribute> list = categoryAttributeService.selectCategoryAttributeList(categoryAttribute);
        ExcelUtil<CategoryAttribute> util = new ExcelUtil<CategoryAttribute>(CategoryAttribute.class);
        util.exportExcel(response, list, "品类属性中间数据");
    }

    /**
     * 获取品类属性中间详细信息
     */
    @RequiresPermissions("product:category_attribute:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(categoryAttributeService.selectCategoryAttributeById(id));
    }

    /**
     * 新增品类属性中间
     */
    @RequiresPermissions("product:category_attribute:add")
    @Log(title = "品类属性中间", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody CategoryAttribute categoryAttribute)
    {
        return toAjax(categoryAttributeService.insertCategoryAttribute(categoryAttribute));
    }

    /**
     * 修改品类属性中间
     */
    @RequiresPermissions("product:category_attribute:edit")
    @Log(title = "品类属性中间", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody CategoryAttribute categoryAttribute)
    {
        return toAjax(categoryAttributeService.updateCategoryAttribute(categoryAttribute));
    }

    /**
     * 删除品类属性中间
     */
    @RequiresPermissions("product:category_attribute:remove")
    @Log(title = "品类属性中间", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(categoryAttributeService.deleteCategoryAttributeByIds(ids));
    }
}
