package com.muyu.product.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.product.domain.CategoryAttributeGroup;
import com.muyu.product.service.ICategoryAttributeGroupService;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 品类属性组中间Controller
 *
 * @author saisai
 * @date 2024-02-29
 */
@RestController
@RequestMapping("/category_attribute_group")
public class CategoryAttributeGroupController extends BaseController
{
    @Autowired
    private ICategoryAttributeGroupService categoryAttributeGroupService;

    /**
     * 查询品类属性组中间列表
     */
    @RequiresPermissions("product:category_attribute_group:list")
    @GetMapping("/list")
    public Result<TableDataInfo<CategoryAttributeGroup>> list(CategoryAttributeGroup categoryAttributeGroup)
    {
        startPage();
        List<CategoryAttributeGroup> list = categoryAttributeGroupService.selectCategoryAttributeGroupList(categoryAttributeGroup);
        return getDataTable(list);
    }

    /**
     * 导出品类属性组中间列表
     */
    @RequiresPermissions("product:category_attribute_group:export")
    @Log(title = "品类属性组中间", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CategoryAttributeGroup categoryAttributeGroup)
    {
        List<CategoryAttributeGroup> list = categoryAttributeGroupService.selectCategoryAttributeGroupList(categoryAttributeGroup);
        ExcelUtil<CategoryAttributeGroup> util = new ExcelUtil<CategoryAttributeGroup>(CategoryAttributeGroup.class);
        util.exportExcel(response, list, "品类属性组中间数据");
    }

    /**
     * 获取品类属性组中间详细信息
     */
    @RequiresPermissions("product:category_attribute_group:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(categoryAttributeGroupService.selectCategoryAttributeGroupById(id));
    }

    /**
     * 新增品类属性组中间
     */
    @RequiresPermissions("product:category_attribute_group:add")
    @Log(title = "品类属性组中间", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody CategoryAttributeGroup categoryAttributeGroup)
    {
        return toAjax(categoryAttributeGroupService.insertCategoryAttributeGroup(categoryAttributeGroup));
    }

    /**
     * 修改品类属性组中间
     */
    @RequiresPermissions("product:category_attribute_group:edit")
    @Log(title = "品类属性组中间", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody CategoryAttributeGroup categoryAttributeGroup)
    {
        return toAjax(categoryAttributeGroupService.updateCategoryAttributeGroup(categoryAttributeGroup));
    }

    /**
     * 删除品类属性组中间
     */
    @RequiresPermissions("product:category_attribute_group:remove")
    @Log(title = "品类属性组中间", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(categoryAttributeGroupService.deleteCategoryAttributeGroupByIds(ids));
    }
}
