package com.muyu.product.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.product.domain.ProductCategory;
import com.muyu.product.service.IProductCategoryService;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 品类商品中间Controller
 *
 * @author Saisai
 * @date 2024-02-29
 */
@RestController
@RequestMapping("/product_category")
public class ProductCategoryController  extends BaseController
{
    @Autowired
    private IProductCategoryService productCategoryService;

    /**
     * 查询品类商品中间列表
     */
    @RequiresPermissions("product:product_category:list")
    @GetMapping("/list")
    public Result<TableDataInfo<ProductCategory>> list(ProductCategory productCategory)
    {
        startPage();
        List<ProductCategory> list = productCategoryService.selectProductCategoryList(productCategory);
        return getDataTable(list);
    }

    /**
     * 导出品类商品中间列表
     */
    @RequiresPermissions("product:product_category:export")
    @Log(title = "品类商品中间", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ProductCategory productCategory)
    {
        List<ProductCategory> list = productCategoryService.selectProductCategoryList(productCategory);
        ExcelUtil<ProductCategory> util = new ExcelUtil<ProductCategory>(ProductCategory.class);
        util.exportExcel(response, list, "品类商品中间数据");
    }

    /**
     * 获取品类商品中间详细信息
     */
    @RequiresPermissions("product:product_category:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(productCategoryService.selectProductCategoryById(id));
    }

    /**
     * 新增品类商品中间
     */
    @RequiresPermissions("product:product_category:add")
    @Log(title = "品类商品中间", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody ProductCategory productCategory)
    {
        return toAjax(productCategoryService.insertProductCategory(productCategory));
    }

    /**
     * 修改品类商品中间
     */
    @RequiresPermissions("product:product_category:edit")
    @Log(title = "品类商品中间", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody ProductCategory productCategory)
    {
        return toAjax(productCategoryService.updateProductCategory(productCategory));
    }

    /**
     * 删除品类商品中间
     */
    @RequiresPermissions("product:product_category:remove")
    @Log(title = "品类商品中间", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(productCategoryService.deleteProductCategoryByIds(ids));
    }
}
