package com.muyu.product.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.product.domain.Rule;
import com.muyu.product.service.IRuleService;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 规格Controller
 *
 * @author saisai
 * @date 2024-02-29
 */
@RestController
@RequestMapping("/rule")
public class RuleController extends BaseController
{
    @Autowired
    private IRuleService ruleService;

    /**
     * 查询规格列表
     */
    @RequiresPermissions("product:rule:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Rule>> list(Rule rule)
    {
        startPage();
        List<Rule> list = ruleService.selectRuleList(rule);
        return getDataTable(list);
    }

    /**
     * 导出规格列表
     */
    @RequiresPermissions("product:rule:export")
    @Log(title = "规格", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Rule rule)
    {
        List<Rule> list = ruleService.selectRuleList(rule);
        ExcelUtil<Rule> util = new ExcelUtil<Rule>(Rule.class);
        util.exportExcel(response, list, "规格数据");
    }

    /**
     * 获取规格详细信息
     */
    @RequiresPermissions("product:rule:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(ruleService.selectRuleById(id));
    }

    /**
     * 新增规格
     */
    @RequiresPermissions("product:rule:add")
    @Log(title = "规格", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody Rule rule)
    {
        return toAjax(ruleService.insertRule(rule));
    }

    /**
     * 修改规格
     */
    @RequiresPermissions("product:rule:edit")
    @Log(title = "规格", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody Rule rule)
    {
        return toAjax(ruleService.updateRule(rule));
    }

    /**
     * 删除规格
     */
    @RequiresPermissions("product:rule:remove")
    @Log(title = "规格", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(ruleService.deleteRuleByIds(ids));
    }
}
