package com.muyu.product.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.muyu.product.mapper.AttributeProductMapper;
import com.muyu.product.domain.AttributeProduct;
import com.muyu.product.service.IAttributeProductService;

/**
 * 商品属性中间表Service业务层处理
 *
 * @author Saisai
 * @date 2024-02-29
 */
@Service
public class AttributeProductServiceImpl extends ServiceImpl<AttributeProductMapper,AttributeProduct> implements IAttributeProductService
{
    @Autowired
    private AttributeProductMapper attributeProductMapper;

    /**
     * 查询商品属性中间表
     *
     * @param id 商品属性中间表主键
     * @return 商品属性中间表
     */
    @Override
    public AttributeProduct selectAttributeProductById(Long id)
    {
        return attributeProductMapper.selectAttributeProductById(id);
    }

    /**
     * 查询商品属性中间表列表
     *
     * @param attributeProduct 商品属性中间表
     * @return 商品属性中间表
     */
    @Override
    public List<AttributeProduct> selectAttributeProductList(AttributeProduct attributeProduct)
    {
        return attributeProductMapper.selectAttributeProductList(attributeProduct);
    }

    /**
     * 新增商品属性中间表
     *
     * @param attributeProduct 商品属性中间表
     * @return 结果
     */
    @Override
    public int insertAttributeProduct(AttributeProduct attributeProduct)
    {
        attributeProduct.setCreateTime(DateUtils.getNowDate());
        return attributeProductMapper.insertAttributeProduct(attributeProduct);
    }

    /**
     * 修改商品属性中间表
     *
     * @param attributeProduct 商品属性中间表
     * @return 结果
     */
    @Override
    public int updateAttributeProduct(AttributeProduct attributeProduct)
    {
        attributeProduct.setUpdateTime(DateUtils.getNowDate());
        return attributeProductMapper.updateAttributeProduct(attributeProduct);
    }

    /**
     * 批量删除商品属性中间表
     *
     * @param ids 需要删除的商品属性中间表主键
     * @return 结果
     */
    @Override
    public int deleteAttributeProductByIds(Long[] ids)
    {
        return attributeProductMapper.deleteAttributeProductByIds(ids);
    }

    /**
     * 删除商品属性中间表信息
     *
     * @param id 商品属性中间表主键
     * @return 结果
     */
    @Override
    public int deleteAttributeProductById(Long id)
    {
        return attributeProductMapper.deleteAttributeProductById(id);
    }
}
