package com.muyu.product.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.muyu.product.mapper.BrandCategoryMapper;
import com.muyu.product.domain.BrandCategory;
import com.muyu.product.service.IBrandCategoryService;

/**
 * 品牌品类中间Service业务层处理
 *
 * @author Saisai
 * @date 2024-02-29
 */
@Service
public class BrandCategoryServiceImpl extends ServiceImpl<BrandCategoryMapper,BrandCategory> implements IBrandCategoryService
{
    @Autowired
    private BrandCategoryMapper brandCategoryMapper;

    /**
     * 查询品牌品类中间
     *
     * @param id 品牌品类中间主键
     * @return 品牌品类中间
     */
    @Override
    public BrandCategory selectBrandCategoryById(Long id)
    {
        return brandCategoryMapper.selectBrandCategoryById(id);
    }

    /**
     * 查询品牌品类中间列表
     *
     * @param brandCategory 品牌品类中间
     * @return 品牌品类中间
     */
    @Override
    public List<BrandCategory> selectBrandCategoryList(BrandCategory brandCategory)
    {
        return brandCategoryMapper.selectBrandCategoryList(brandCategory);
    }

    /**
     * 新增品牌品类中间
     *
     * @param brandCategory 品牌品类中间
     * @return 结果
     */
    @Override
    public int insertBrandCategory(BrandCategory brandCategory)
    {
        brandCategory.setCreateTime(DateUtils.getNowDate());
        return brandCategoryMapper.insertBrandCategory(brandCategory);
    }

    /**
     * 修改品牌品类中间
     *
     * @param brandCategory 品牌品类中间
     * @return 结果
     */
    @Override
    public int updateBrandCategory(BrandCategory brandCategory)
    {
        brandCategory.setUpdateTime(DateUtils.getNowDate());
        return brandCategoryMapper.updateBrandCategory(brandCategory);
    }

    /**
     * 批量删除品牌品类中间
     *
     * @param ids 需要删除的品牌品类中间主键
     * @return 结果
     */
    @Override
    public int deleteBrandCategoryByIds(Long[] ids)
    {
        return brandCategoryMapper.deleteBrandCategoryByIds(ids);
    }

    /**
     * 删除品牌品类中间信息
     *
     * @param id 品牌品类中间主键
     * @return 结果
     */
    @Override
    public int deleteBrandCategoryById(Long id)
    {
        return brandCategoryMapper.deleteBrandCategoryById(id);
    }
}
