package com.muyu.product.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.DateUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.muyu.product.mapper.CategoryAttributeMapper;
import com.muyu.product.domain.CategoryAttribute;
import com.muyu.product.service.ICategoryAttributeService;

/**
 * 品类属性中间Service业务层处理
 *
 * @author Saisai
 * @date 2024-02-29
 */
@Slf4j
@Service
public class CategoryAttributeServiceImpl extends ServiceImpl<CategoryAttributeMapper,CategoryAttribute> implements ICategoryAttributeService
{
    @Autowired
    private CategoryAttributeMapper categoryAttributeMapper;

    /**
     * 查询品类属性中间
     *
     * @param id 品类属性中间主键
     * @return 品类属性中间
     */
    @Override
    public CategoryAttribute selectCategoryAttributeById(Long id)
    {
        return categoryAttributeMapper.selectCategoryAttributeById(id);
    }

    /**
     * 查询品类属性中间列表
     *
     * @param categoryAttribute 品类属性中间
     * @return 品类属性中间
     */
    @Override
    public List<CategoryAttribute> selectCategoryAttributeList(CategoryAttribute categoryAttribute)
    {
        return categoryAttributeMapper.selectCategoryAttributeList(categoryAttribute);
    }

    /**
     * 新增品类属性中间
     *
     * @param categoryAttribute 品类属性中间
     * @return 结果
     */
    @Override
    public int insertCategoryAttribute(CategoryAttribute categoryAttribute)
    {
        categoryAttribute.setCreateTime(DateUtils.getNowDate());
        return categoryAttributeMapper.insertCategoryAttribute(categoryAttribute);
    }

    /**
     * 修改品类属性中间
     *
     * @param categoryAttribute 品类属性中间
     * @return 结果
     */
    @Override
    public int updateCategoryAttribute(CategoryAttribute categoryAttribute)
    {
        categoryAttribute.setUpdateTime(DateUtils.getNowDate());
        return categoryAttributeMapper.updateCategoryAttribute(categoryAttribute);
    }

    /**
     * 批量删除品类属性中间
     *
     * @param ids 需要删除的品类属性中间主键
     * @return 结果
     */
    @Override
    public int deleteCategoryAttributeByIds(Long[] ids)
    {
        return categoryAttributeMapper.deleteCategoryAttributeByIds(ids);
    }

    /**
     * 删除品类属性中间信息
     *
     * @param id 品类属性中间主键
     * @return 结果
     */
    @Override
    public int deleteCategoryAttributeById(Long id)
    {
        return categoryAttributeMapper.deleteCategoryAttributeById(id);
    }
}
