package com.muyu.product.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.muyu.product.mapper.RuleProductMapper;
import com.muyu.product.domain.RuleProduct;
import com.muyu.product.service.IRuleProductService;

/**
 * 规格商品中间Service业务层处理
 *
 * @author saisai
 * @date 2024-02-29
 */
@Service
public class RuleProductServiceImpl extends ServiceImpl<RuleProductMapper,RuleProduct> implements IRuleProductService
{
    @Autowired
    private RuleProductMapper ruleProductMapper;

    /**
     * 查询规格商品中间
     *
     * @param id 规格商品中间主键
     * @return 规格商品中间
     */
    @Override
    public RuleProduct selectRuleProductById(Long id)
    {
        return ruleProductMapper.selectRuleProductById(id);
    }

    /**
     * 查询规格商品中间列表
     *
     * @param ruleProduct 规格商品中间
     * @return 规格商品中间
     */
    @Override
    public List<RuleProduct> selectRuleProductList(RuleProduct ruleProduct)
    {
        return ruleProductMapper.selectRuleProductList(ruleProduct);
    }

    /**
     * 新增规格商品中间
     *
     * @param ruleProduct 规格商品中间
     * @return 结果
     */
    @Override
    public int insertRuleProduct(RuleProduct ruleProduct)
    {
        ruleProduct.setCreateTime(DateUtils.getNowDate());
        return ruleProductMapper.insertRuleProduct(ruleProduct);
    }

    /**
     * 修改规格商品中间
     *
     * @param ruleProduct 规格商品中间
     * @return 结果
     */
    @Override
    public int updateRuleProduct(RuleProduct ruleProduct)
    {
        ruleProduct.setUpdateTime(DateUtils.getNowDate());
        return ruleProductMapper.updateRuleProduct(ruleProduct);
    }

    /**
     * 批量删除规格商品中间
     *
     * @param ids 需要删除的规格商品中间主键
     * @return 结果
     */
    @Override
    public int deleteRuleProductByIds(Long[] ids)
    {
        return ruleProductMapper.deleteRuleProductByIds(ids);
    }

    /**
     * 删除规格商品中间信息
     *
     * @param id 规格商品中间主键
     * @return 结果
     */
    @Override
    public int deleteRuleProductById(Long id)
    {
        return ruleProductMapper.deleteRuleProductById(id);
    }
}
