package com.muyu.product.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.muyu.product.mapper.RuleMapper;
import com.muyu.product.domain.Rule;
import com.muyu.product.service.IRuleService;

/**
 * 规格Service业务层处理
 *
 * @author saisai
 * @date 2024-02-29
 */
@Service
public class RuleServiceImpl extends ServiceImpl<RuleMapper,Rule> implements IRuleService
{
    @Autowired
    private RuleMapper ruleMapper;

    /**
     * 查询规格
     *
     * @param id 规格主键
     * @return 规格
     */
    @Override
    public Rule selectRuleById(Long id)
    {
        return ruleMapper.selectRuleById(id);
    }

    /**
     * 查询规格列表
     *
     * @param rule 规格
     * @return 规格
     */
    @Override
    public List<Rule> selectRuleList(Rule rule)
    {
        return ruleMapper.selectRuleList(rule);
    }

    /**
     * 新增规格
     *
     * @param rule 规格
     * @return 结果
     */
    @Override
    public int insertRule(Rule rule)
    {
        rule.setCreateTime(DateUtils.getNowDate());
        return ruleMapper.insertRule(rule);
    }

    /**
     * 修改规格
     *
     * @param rule 规格
     * @return 结果
     */
    @Override
    public int updateRule(Rule rule)
    {
        rule.setUpdateTime(DateUtils.getNowDate());
        return ruleMapper.updateRule(rule);
    }

    /**
     * 批量删除规格
     *
     * @param ids 需要删除的规格主键
     * @return 结果
     */
    @Override
    public int deleteRuleByIds(Long[] ids)
    {
        return ruleMapper.deleteRuleByIds(ids);
    }

    /**
     * 删除规格信息
     *
     * @param id 规格主键
     * @return 结果
     */
    @Override
    public int deleteRuleById(Long id)
    {
        return ruleMapper.deleteRuleById(id);
    }
}
